@@ -3,7 +3,7 @@
 #' Generates a data frame of pairwise linkage disequilibrium
 #' statistics.
 #'
-#' @param snps list of between 2 - 1,000 variants, using an rsID or chromosome coordinate (e.g. "chr7:24966446")
+#' @param snps list of between 2 - 2500 variants, using an rsID or chromosome coordinate (e.g. "chr7:24966446")
 #' @param pop a 1000 Genomes Project population, (e.g. YRI or CEU), multiple allowed, default = "CEU"
 #' @param r2d r2d, either "r2" for LD R2 or "d" for LD D', default = "r2"
 #' @param token LDlink provided user token, default = NULL, register for token at \url{https://ldlink.nih.gov/?tab=apiaccess}
@@ -66,8 +66,8 @@ LDmatrix <- function(snps,
 
 
   # Checking arguments for valid input
-  if(!(length(snps) > 1) & (length(snps) <= 1000)) {
-    stop("Input is between 2 to 1000 variants.")
+  if(length(snps) < 2 || length(snps) > 2500) {
+    stop("Input is between 2 to 2500 variants.")
   }
 
   for(i in 1:length(snps)) {
@@ -118,7 +118,7 @@ LDmatrix <- function(snps,
     message("\nLDlink server is working...\n")
   }
 
-  # GET command
+  # POST command
   # raw_out <-  httr::POST(url=url_str, body=jsonbody, encode="json")
   raw_out <-  httr::POST(url=url_str, body=jsonbody, encode="json")
   httr::stop_for_status(raw_out)
